<?php
require_once("../../classes/class.users.php");
require_once("../../classes/class.validation.php");
require_once("../../classes/class.authentication.php");

require_once("../../classes/school_administration/class.classes.php");
require_once('../../classes/school_administration/class.class_sections.php');
require_once('../../classes/school_administration/class.students.php');
require_once('../../classes/school_administration/class.student_details.php');

require_once('../../classes/examination/class.exam_types.php');

require_once("../../includes/global_defaults.inc.php");

//1. RECHECK IF THE USER IS VALID //
try
{
	$AuthObject = new ApplicationAuthentication;
	$LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}
catch (Exception $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}

if ($LoggedUser->HasPermissionForTask(TASK_ADD_STUDENT_PHYSIQUE) !== true)
{
    header('location:/admin/unauthorized_login_admin.php');
    exit;
}

// END OF 1. //

$HasErrors = false;

$ClassList =  array();
$ClassList = AddedClass::GetActiveClasses();

$ExamTypeList =  array();
$ExamTypeList = ExamType::GetActiveExamTypes();

$ClassSectionsList =  array();

$StudentsList = array();

$Clean = array();
$Clean['ClassID'] = 0;
$Clean['ExamTypeID'] = 0;

$Clean['StudentPhysiqueDetails'] = array();

$Clean['HeightList'] = array();
$Clean['WeightList'] = array();

$Clean['Process'] = 0;

if (isset($_POST['hdnProcess']))
{
	$Clean['Process'] = (int) $_POST['hdnProcess'];
}
switch ($Clean['Process'])
{
	case 1:
        if (isset($_POST['txtHeight']) && is_array($_POST['txtHeight'])) 
        {
            $Clean['HeightList'] = $_POST['txtHeight'];
        }

        if (isset($_POST['txtWeight']) && is_array($_POST['txtWeight'])) 
        {
            $Clean['WeightList'] = $_POST['txtWeight'];
        }

        if (isset($_POST['hdnClassSectionID'])) 
        {
            $Clean['ClassSectionID'] = (int) $_POST['hdnClassSectionID'];
        }

        if (isset($_POST['hdnExamTypeID'])) 
        {
            $Clean['ExamTypeID'] = (int) $_POST['hdnExamTypeID'];
        }

        $NewRecordValidator = new Validator();

        if (count($Clean['HeightList']) <= 0) 
        {
            $NewRecordValidator->AttachTextError('Please enter details.');
            $HasErrors = true;
            break;
        }

        $StudentsList = StudentDetail::GetStudentsByClassSectionID($Clean['ClassSectionID'], 'Active');

        foreach ($Clean['HeightList'] as $StudentID => $Height) 
        {
            if (!array_key_exists($StudentID, $StudentsList))
            {
                header('location:/admin/error.php');
                exit;
            }
            
            if ($Height != '')
            {
                $NewRecordValidator->ValidateNumeric($Height, 'Height amount is required and should be numeric ', 0);
            }

            $Clean['StudentPhysiqueDetails'][$StudentID]['Height'] = $Height;
        }

        foreach ($Clean['WeightList'] as $StudentID => $Weight) 
        {
            if (!array_key_exists($StudentID, $StudentsList))
            {
                header('location:/admin/error.php');
                exit;
            }

            if ($Weight != '')
            {
                $NewRecordValidator->ValidateNumeric($Weight, 'Weight amount is required and should be numeric ', 0);
            }

            $Clean['StudentPhysiqueDetails'][$StudentID]['Weight'] = $Weight;
        }

        if ($NewRecordValidator->HasNotifications())
        {
            $HasErrors = true;
            break;
        }

        if (!ExamType::SaveStudentPhysiqueDetails($Clean['ExamTypeID'], $Clean['StudentPhysiqueDetails']))
        {
            $NewRecordValidator->AttachTextError('Error in executing query.');
            $HasErrors = true;
            break;
        }

        header('location:add_student_physique.php?Mode=AS');
        exit;
    break;

	case 7:
        if (isset($_POST['drdClass'])) 
        {
            $Clean['ClassID'] = (int) $_POST['drdClass'];
        }

        if (isset($_POST['drdClassSection'])) 
        {
            $Clean['ClassSectionID'] = (int) $_POST['drdClassSection'];
        }

        if (isset($_POST['drdExamType'])) 
        {
            $Clean['ExamTypeID'] = (int) $_POST['drdExamType'];
        }
        
        $NewRecordValidator = new Validator();

        if ($NewRecordValidator->ValidateInSelect($Clean['ClassID'], $ClassList, 'Unknown error, please try again.')) 
        {
            $CurrentClass = new AddedClass($Clean['ClassID']);
            $ClassSectionsList = ClassSections::GetClassSections($Clean['ClassID']);

            $NewRecordValidator->ValidateInSelect($Clean['ClassSectionID'], $ClassSectionsList, 'Unknown error, please try again.');

            $NewRecordValidator->ValidateInSelect($Clean['ExamTypeID'], $ExamTypeList, 'Please select a exam type.');
        }
        
        if ($NewRecordValidator->HasNotifications())
        {
            $HasErrors = true;
            break;
        }

        $StudentsList = StudentDetail::GetStudentsByClassSectionID($Clean['ClassSectionID'], 'Active');

        $Clean['StudentPhysiqueDetails'] = ExamType::GetAllStudentPhysiqueDetails($Clean['ClassSectionID'], $Clean['ExamTypeID']);           
    break;
}

$LandingPageMode = '';
if (isset($_GET['Mode']))
{
    $LandingPageMode = $_GET['Mode'];
}

require_once('../html_header.php');
?>
<title>Student Physique Details</title>
<link href="../vendor/jquery-ui/jquery-ui.min.css" rel="stylesheet">
</head>

<body>

    <div id="wrapper">
    	<!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
<?php 
			require_once('../site_header.php');
			require_once('../left_navigation_menu.php');
?>                    
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="page-header">Student Physique Details</h1>
                </div>
                <!-- /.col-lg-12 -->
            </div>
             <form class="form-horizontal" name="AddFeedStudentmarks" action="add_student_physique.php" method="post">
            	<div class="panel panel-default">
                    <div class="panel-heading">
                        Enter Details
                    </div>
                    <div class="panel-body">
<?php
						if ($HasErrors == true)
						{
							echo $NewRecordValidator->DisplayErrors();
						}
						else if ($LandingPageMode == 'AS')
                        {
                            echo '<div class="alert alert-success alert-top-margin">Record saved successfully.</div><br>';
                        }
                        else if ($LandingPageMode == 'SS')
                        {
                            echo '<div class="alert alert-success alert-top-margin">SMS send successfully.</div><br>';
                        }
?>                      
						<div class="form-group">
                            <label for="Class" class="col-lg-2 control-label">Class</label>
                            <div class="col-lg-4">
                                <select class="form-control"  name="drdClass" id="Class">
                                    <option  value="0" >-- Select Class --</option>
<?php
                                    if (is_array($ClassList) && count($ClassList) > 0)
                                    {
                                        foreach ($ClassList as $ClassID => $ClassName)
	                                    {
	?>
	                                        <option <?php echo ($ClassID == $Clean['ClassID'] ? 'selected="selected"' : ''); ?> value="<?php echo $ClassID; ?>"><?php echo $ClassName; ?></option>
	<?php
	                                    }
                                    }
?>
                                </select>
                            </div>
                            <label for="ClassSection" class="col-lg-2 control-label">Section</label>
                            <div class="col-lg-4">
                                <select class="form-control" name="drdClassSection" id="ClassSection">
                                    <option value="0">-- Select Section --</option>
<?php
                                    if (is_array($ClassSectionsList) && count($ClassSectionsList) > 0)
                                    {
                                        foreach ($ClassSectionsList as $ClassSectionID => $SectionName) 
                                        {
                                            echo '<option ' . ($Clean['ClassSectionID'] == $ClassSectionID ? 'selected="selected"' : '') . ' value="' . $ClassSectionID . '">' . $SectionName . '</option>' ;
                                        }
                                    }
?>
                                </select>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="ExamType" class="col-lg-2 control-label">Exam Type</label>
                            <div class="col-lg-4">
                                <select class="form-control" name="drdExamType" id="ExamType">
                                        <option  value="0" >-- Select Exam Type --</option>
<?php
                                        if (is_array($ExamTypeList) && count($ExamTypeList) > 0)
                                        {
                                            foreach ($ExamTypeList as $ExamTypeID => $ExamType) 
                                            {
                                                echo '<option ' . ($Clean['ExamTypeID'] == $ExamTypeID ? 'selected="selected"' : '') . ' value="' . $ExamTypeID . '">' . $ExamType . '</option>' ;
                                            }
                                        }
?>
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="form-group">
                        <div class="col-sm-offset-2 col-lg-10">
                        	<input type="hidden" name="hdnProcess" value="7" />
							<button type="submit" class="btn btn-primary"><i class="fa fa-search"></i>&nbsp;Search</button>
                        </div>
                  	</div>
                </div>
            </form>
<?php
        if ($Clean['Process'] == 7 && $HasErrors == false || $Clean['Process'] == 1)
        {
?>
            <div class="panel panel-default">
                <div class="panel-heading">
                    Enter Student Physique Details
                </div>
                <div class="panel-body">
                    <form class="form-horizontal" name="AddFeedStudentmarks" action="add_student_physique.php" method="post">
                        <div class="row" id="RecordTable">
                            <div class="col-lg-12">
                                <table width="100%" class="table table-striped table-bordered table-hover">
                                    <thead>
                                        <tr>
                                            <th>S. No</th>          
                                            <th>Student Name</th>
                                            <th>Height (cm)</th>
                                            <th>Weight (kg)</th>
                                        </tr>
									</thead>
									<tbody>
<?php                         
                                        $RowCounter = 1;
                                        if (count($StudentsList) > 0) 
                                        {
                                            foreach ($StudentsList as $StudentID => $StudentDetails) 
                                            {
?>
                                           <tr>
                                                <td><?php echo $RowCounter++; ?></td>
                                                <td><?php echo $StudentDetails['FirstName'] . $StudentDetails['LastName'] .'('. $StudentDetails['RollNumber']. ')'; ?></td>
                                                <td>
                                                    <input type="text" class="form-control" id="<?php echo $StudentID; ?>" maxlength="10" name="txtHeight[<?php echo $StudentID ;?>]" value="<?php echo(array_key_exists($StudentID, $Clean['StudentPhysiqueDetails']) ? ( $Clean['StudentPhysiqueDetails'][$StudentID]['Height'] > 0) ? $Clean['StudentPhysiqueDetails'][$StudentID]['Height'] : '' : '') ; ?>"/> 
                                                </td>
                                                <td>
                                                    <input type="text" class="form-control" id="<?php echo $StudentID; ?>" maxlength="10" name="txtWeight[<?php echo $StudentID ;?>]" value="<?php echo(array_key_exists($StudentID, $Clean['StudentPhysiqueDetails']) ? ($Clean['StudentPhysiqueDetails'][$StudentID]['Weight'] > 0) ? $Clean['StudentPhysiqueDetails'][$StudentID]['Weight'] : '' : '') ; ?>"/>
                                            </tr>                      
<?php
                                            }
                                        }
?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
						<div class="form-group">
                            <div class="col-sm-offset-2 col-lg-10">
                                <input type="hidden" name="hdnProcess" value="1" />
                                <input type="hidden" name="hdnClassSectionID" value="<?php echo $Clean['ClassSectionID']; ?>" />
                                <input type="hidden" name="hdnExamTypeID" value="<?php echo $Clean['ExamTypeID'];?>" />
                                <button type="submit" class="btn btn-primary"><i class="fa fa-save"></i>&nbsp;Save</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
<?php
        }
?>
        </div>
        <!-- /#page-wrapper -->

    </div>
    <!-- /#wrapper -->
<?php
require_once('../footer.php');
?>
<script src="../vendor/jquery-ui/jquery-ui.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.2/jquery.fancybox.min.js"></script>
<script type="text/javascript">
$(document).ready(function(){

	$('#Class').change(function(){

        var ClassID = parseInt($('#Class').val());
        
        if (ClassID <= 0)
        {
            $('#ClassSection').html('<option value="0">-- Select Section --</option>');
            return;
        }
        
        $.post("/xhttp_calls/get_sections_by_classs.php", {SelectedClassID:ClassID}, function(data)
        {
            ResultArray = data.split("|*****|");
            
            if (ResultArray[0] == 'error')
            {
                alert (ResultArray[1]);
                return false;
            }
            else
            {
                $('#ClassSection').html('<option value="0">-- Select Section --</option>' + ResultArray[1]);
            }
        });
    });
});
</script>
</body>
</html>