<?php
require_once("../../classes/class.users.php");
require_once("../../classes/class.validation.php");
require_once("../../classes/class.authentication.php");
require_once("../../classes/class.date_processing.php");

require_once("../../classes/school_administration/class.classes.php");
require_once('../../classes/school_administration/class.class_sections.php');
require_once('../../classes/school_administration/class.section_master.php');

require_once("../../classes/academic_supervision/class.chapters.php");
require_once("../../classes/academic_supervision/class.chapter_topics.php");
require_once("../../classes/academic_supervision/class.student_diaries.php");

require_once("../../includes/global_defaults.inc.php");

//1. RECHECK IF THE USER IS VALID //
try
{
	$AuthObject = new ApplicationAuthentication;
	$LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}
catch (Exception $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}
// END OF 1. //

if ($LoggedUser->HasPermissionForTask(TASK_EDIT_STUDENT_ASSIGNMENT) !== true)
{
	header('location:/admin/unauthorized_login_admin.php');
	exit;
}

$Clean = array();

$Clean['DiaryID'] = 0;

if (isset($_GET['DiaryID']))
{
	$Clean['DiaryID'] = (int) $_GET['DiaryID'];
}
else if (isset($_POST['hdnDiaryID']))
{
	$Clean['DiaryID'] = (int) $_POST['hdnDiaryID'];
}

if ($Clean['DiaryID'] <= 0)
{
	header('location:../error.php');
	exit;
}

try
{
	$StudentDiaryToEdit = new StudentDiary($Clean['DiaryID']);
}
catch (ApplicationDBException $e)
{
	header('location:../error.php');
	exit;
}
catch (Exception $e)
{
	header('location:../error.php');
	exit;
}

$AllDiaryImages = array();

$ClassList = array();
$ClassList = AddedClass::GetActiveClasses();

$AllSectionMasters = array();
$AllSectionMasters = SectionMaster::GetActiveSectionMasters();

$ClassSectionsList = array();
$HasErrors = false;

$Clean['Process'] = 0;

$Clean['ClassID'] = 0;
$Clean['ClassSectionID'] = 0;

$Clean['DiaryHeading'] = '';
$Clean['Diary'] = '';
$Clean['IsActive'] = 0;

if (isset($_POST['hdnProcess']))
{
	$Clean['Process'] = (int) $_POST['hdnProcess'];
}
else if (isset($_GET['Process']))
{
	$Clean['Process'] = (int) $_GET['Process'];
}
switch ($Clean['Process'])
{
	case 3:
		if (isset($_POST['drdClass']))
		{
			$Clean['ClassID'] = (int) $_POST['drdClass'];
		}
		if (isset($_POST['drdClassSection']))
		{
			$Clean['ClassSectionID'] = (int) $_POST['drdClassSection'];
		}

		if (isset($_POST['txtDiaryHeading']))
		{
			$Clean['DiaryHeading'] = strip_tags(trim($_POST['txtDiaryHeading']));
		}
		if (isset($_POST['txtDiary']))
		{
			$Clean['Diary'] = strip_tags(trim($_POST['txtDiary']));
		}

		if (isset($_POST['chkIsActive']))
		{
			$Clean['IsActive'] = 1;
		}

		$NewRecordValidator = new Validator();

		if ($NewRecordValidator->ValidateInSelect($Clean['ClassID'], $ClassList, 'Please select a valid class.'))
		{
			$ClassSectionsList = ClassSections::GetClassSections($Clean['ClassID']);

			$NewRecordValidator->ValidateInSelect($Clean['ClassSectionID'], $ClassSectionsList, 'Please select a valid section.');
		}

		$NewRecordValidator->ValidateStrings($Clean['DiaryHeading'], 'Diary heading is required and should be between 1 and 150 characters.', 1, 150);
		$NewRecordValidator->ValidateStrings($Clean['Diary'], 'Diary is required and should be between 5 and 2000 characters.', 5, 2000);

		if ($NewRecordValidator->HasNotifications())
		{
			$HasErrors = true;
			break;
		}

		$StudentDiaryToEdit->SetClassSectionID($Clean['ClassSectionID']);

		$StudentDiaryToEdit->SetHeading($Clean['DiaryHeading']);
		$StudentDiaryToEdit->SetDetails($Clean['Diary']);

		$StudentDiaryToEdit->SetIsActive($Clean['IsActive']);

		if (!$StudentDiaryToEdit->Save())
		{
			$NewRecordValidator->AttachTextError(ProcessErrors($StudentDiaryToEdit->GetLastErrorCode()));
			$HasErrors = true;

			break;
		}

		header('location:view_ediaries.php?Mode=UD');
		exit;
		break;

	case 2:
		$Clean['ClassSectionID'] = $StudentDiaryToEdit->GetClassSectionID();
		$ClassSectionObj = New ClassSections($Clean['ClassSectionID']);
		$Clean['ClassID'] = $ClassSectionObj->GetClassID();
		$ClassSectionsList = ClassSections::GetClassSections($Clean['ClassID']);
		$Clean['DiaryHeading'] = $StudentDiaryToEdit->GetHeading();
		$Clean['Diary'] = $StudentDiaryToEdit->GetDetails();
		$Clean['IsActive'] = $StudentDiaryToEdit->GetIsActive();
	break;
}

require_once('../html_header.php');
?>
<title>Edit Student Diary</title>
<link href="../vendor/jquery-ui/jquery-ui.min.css" rel="stylesheet">
<link rel="stylesheet" type="text/css" href="https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.2/jquery.fancybox.min.css">
</head>

<body>

    <div id="wrapper">
        <!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
			<?php
			require_once('../site_header.php');
			require_once('../left_navigation_menu.php');
			?>                    
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="page-header">Edit Student Diary</h1>
                </div> 
                <!-- /.col-lg-12 -->
            </div>
			<form class="form-horizontal" name="EditChapter" action="edit_student_diary.php" method="post">
                <div class="panel panel-default">
                    <div class="panel-heading">
                        Enter Diary Details
                    </div>
                    <div class="panel-body">
						<?php
						if ($HasErrors == true)
						{
							echo $NewRecordValidator->DisplayErrors();
						}
						?>                    
                        <div class="form-group">
                            <label for="Class" class="col-lg-2 control-label">Class List</label>
                            <div class="col-lg-3">
                                <select class="form-control"  name="drdClass" id="Class">
                                    <option  value="0" >-- Select Class --</option>
									<?php
									if (is_array($ClassList) && count($ClassList) > 0)
									{
										foreach ($ClassList as $ClassID => $ClassName)
										{
											?>
											<option <?php echo ($ClassID == $Clean['ClassID'] ? 'selected="selected"' : ''); ?> value="<?php echo $ClassID; ?>"><?php echo $ClassName; ?></option>
											<?php
										}
									}
									?>
                                </select>
                            </div>
                            <label for="ClassSection" class="col-lg-2 control-label">Section</label>
                            <div class="col-lg-3">
                                <select class="form-control" name="drdClassSection" id="ClassSection">
                                    <option value="0">-- Select Section --</option>
									<?php
									if (is_array($ClassSectionsList) && count($ClassSectionsList) > 0)
									{
										foreach ($ClassSectionsList as $ClassSectionID => $SectionName)
										{
											echo '<option ' . ($Clean['ClassSectionID'] == $ClassSectionID ? 'selected="selected"' : '') . ' value="' . $ClassSectionID . '">' . $SectionName . '</option>';
										}
									}
									?>
                                </select>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="DiaryHeading" class="col-lg-2 control-label">Diary Heading</label>
                            <div class="col-lg-8">
                                <input class="form-control" type="text" id="DiaryHeading" name="txtDiaryHeading" value="<?php echo $Clean['DiaryHeading']; ?>" />
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="Diary" class="col-lg-2 control-label">Diary</label>
                            <div class="col-lg-8">
                                <textarea class="form-control"  id="Diary" name="txtDiary"><?php echo $Clean['Diary']; ?></textarea>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="IsActive" class="col-lg-2 control-label">Is Active</label>
                            <div class="col-lg-4">
                                <input type="checkbox" id="IsActive" name="chkIsActive" <?php echo ($Clean['IsActive'] == 1) ? 'checked="checked"' : ''; ?> value="1" />
                            </div>
                        </div>
                        <div class="form-group">
							<div class="col-sm-offset-2 col-lg-10">
								<input type="hidden" name="hdnProcess" value="3"/>
								<input type="hidden" name="hdnDiaryID" value="<?php echo $Clean['DiaryID']; ?>" />
								<button type="submit" class="btn btn-primary"><i class="fa fa-upload"></i>&nbsp;Update</button>
							</div>
						</div>
                    </div>
                </div>
            </form>
        </div>
        <!-- /#page-wrapper -->

    </div>
    <!-- /#wrapper -->
	<?php
	require_once('../footer.php');
	?>
	<script src="../vendor/jquery-ui/jquery-ui.min.js"></script>
	<script src="https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.2/jquery.fancybox.min.js"></script>
	<script type="text/javascript">
		$ (document).ready (function ()
		{
			$ ('#Class').change (function ()
			{
				var ClassID = parseInt ($ ('#Class').val ());
				if (ClassID <= 0)
				{
					$ ('#ClassSection').html ('<option value="0">-- Select Section --</option>');
					return;
				}

				$.post ("/xhttp_calls/get_sections_by_classs.php", {SelectedClassID: ClassID}, function ( data )
				{
					ResultArray = data.split ("|*****|");

					if (ResultArray[0] == 'error')
					{
						alert (ResultArray[1]);
						return false;
					}
					else
					{
						$ ('#ClassSection').html ('<option value="0">-- Select Section --</option>' + ResultArray[1]);
					}
				});
			});
		});
	</script>
</body>
</html>