<?php
require_once($_SERVER['DOCUMENT_ROOT'] . '/classes/class.db_connect.php');
error_reporting(E_ALL);

class ExamType
{
	// CLASS MEMBERS ARE DEFINED HERE	//
	private $LastErrorCode;
	private $DBObject; // VARIABLE TO HOLD THE DB CONNECTION //
	
	private $ExamTypeID;
	private $ExamType;
	
	private $ExamStartDate;
	private $ExamEndDate;

	private $IsActive;
	private $IsVisibleForParent;

	private $CreateUserID;
	private $CreateDate;
	
	// PUBLIC METHODS START HERE	//
	public function __construct($ExamTypeID = 0)
	{
		$this->DBObject = new DBConnect;
		$this->LastErrorCode = 0;
		
		if($ExamTypeID != 0)
		{
			$this->ExamTypeID = $ExamTypeID;
			// SET THE VALUES FROM THE DATABASE.
			$this->GetExamTypeByID();
		}
		else
		{
			//SET THE DEFAULT VALUES TO LOOK ATTRIBUTES
			$this->ExamTypeID = 0;
			$this->ExamType = '';
            
            $this->ExamStartDate = '0000-00-00';
			$this->ExamEndDate = '0000-00-00';
			
			$this->IsActive = 0;
			$this->IsVisibleForParent = 1;

			$this->CreateUserID = 0;
			$this->CreateDate = '0000-00-00 00:00:00';
		}
	}
	
	// GETTER AND SETTER FUNCTIONS START HERE	//
	public function GetExamTypeID()
	{
		return $this->ExamTypeID;
	}
	
	public function GetExamType()
	{
		return $this->ExamType;
	}
	public function SetExamType($ExamType)
	{
		$this->ExamType = $ExamType;
	}
	
	public function GetExamStartDate()
	{
		return $this->ExamStartDate;
	}
	public function SetExamStartDate($ExamStartDate)
	{
		$this->ExamStartDate = $ExamStartDate;
	}

	public function GetExamEndDate()
	{
		return $this->ExamEndDate;
	}
	public function SetExamEndDate($ExamEndDate)
	{
		$this->ExamEndDate = $ExamEndDate;
	}

	public function GetIsActive()
	{
		return $this->IsActive;
	}
	public function SetIsActive($IsActive)
	{
		$this->IsActive = $IsActive;
	}
	
	public function GetIsVisibleForParent()
	{
		return $this->IsVisibleForParent;
	}
	public function SetIsVisibleForParent($IsVisibleForParent)
	{
		$this->IsVisibleForParent = $IsVisibleForParent;
	}

	public function GetCreateUserID()
	{
		return $this->CreateUserID;
	}
	public function SetCreateUserID($CreateUserID)
	{
		$this->CreateUserID = $CreateUserID;
	}

	public function GetCreateDate()
	{
		return $this->CreateDate;
	}
	
	public function GetLastErrorCode()
	{
		return $this->LastErrorCode;
	}
	
	//  END OF GETTER AND SETTER FUNCTIONS 	//
	
	public function Save()
	{
		try
		{
			return $this->SaveDetails();
		}
		catch (ApplicationDBException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (ApplicationARException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (Exception $e)
		{
			$this->LastErrorCode = APP_ERROR_UNDEFINED_ERROR;
			return false;
		}
	}
	
	public function Remove()
    {
        try
        {
            $this->RemoveExamType();
            return true;
        }
        catch (ApplicationDBException $e)
        {
            $this->LastErrorCode = $e->getCode();
            return false;
        }
        catch (ApplicationARException $e)
        {
            $this->LastErrorCode = $e->getCode();
            return false;
        }
        catch (Exception $e)
        {
            $this->LastErrorCode = APP_ERROR_UNDEFINED_ERROR;
            return false;
        }
    }

    public function CheckDependencies()
    {
        try
        {
            $RSExamTypeCount = $this->DBObject->Prepare('SELECT COUNT(*) AS totalRecords FROM aem_exams WHERE examTypeID = :|1;');
            $RSExamTypeCount->Execute($this->ExamTypeID);

            if ($RSExamTypeCount->FetchRow()->totalRecords > 0) 
            {
                return true;
            }

            return false;
        }
        catch (ApplicationDBException $e)
        {
            error_log('DEBUG: ApplicationDBException at ExamType::CheckDependencies(). Stack Trace: ' . $e->getTraceAsString());
            return true;
        }
        catch (Exception $e)
        {
            error_log('DEBUG: ApplicationDBException at ExamType::CheckDependencies(). Stack Trace: ' . $e->getTraceAsString());
            return true;
        }       
    }
    
    public function SaveStudentExamRemark($StudentRemarkList, $ClassSectionID)
    {
        try
        {
            foreach ($StudentRemarkList as $StudentID => $Remark)
            {
                
                $RSSearch = $this->DBObject->Prepare('SELECT studentExamRemarkID FROM aem_student_exam_remark WHERE examTypeID = :|1 AND classSectionID = :|2 AND studentID = :|3 LIMIT 1;');
    			$RSSearch->Execute($this->ExamTypeID, $ClassSectionID, $StudentID);
    			
    			if ($RSSearch->Result->num_rows > 0)
    			{
    				$RSUpdate = $this->DBObject->Prepare('UPDATE aem_student_exam_remark
        													SET	remark = :|1
        													WHERE studentExamRemarkID = :|2
        													LIMIT 1;');
        													
        			$RSUpdate->Execute($Remark, $RSSearch->FetchRow()->studentExamRemarkID);
    			}
    			else
    			{
    			    $RSSave = $this->DBObject->Prepare('INSERT INTO aem_student_exam_remark (examTypeID, classSectionID, studentID, remark, createUserID, createDate)
        												    VALUES (:|1, :|2, :|3, :|4, :|5, NOW());');
                    $RSSave->Execute($this->ExamTypeID, $ClassSectionID, $StudentID, $Remark, $this->CreateUserID);      
    			}
            }

            return true;
        }
        catch (ApplicationDBException $e)
        {
            error_log('DEBUG: ApplicationDBException at ExamType::SaveStudentExamRemark(). Stack Trace: ' . $e->getTraceAsString());
            return false;
        }
        catch (Exception $e)
        {
            error_log('DEBUG: ApplicationDBException at ExamType::SaveStudentExamRemark(). Stack Trace: ' . $e->getTraceAsString());
            return false;
        }       
    }
		
	// END OF PUBLIC METHODS	//
		
	// START OF STATIC METHODS	//
	static function GetAllExamTypes()
	{
		$AllExamTypes = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT aet.*, u.userName AS createUserName FROM aem_exam_types aet
												INNER JOIN users u ON aet.createUserID = u.userID 
												ORDER BY aet.examType;');
			$RSSearch->Execute();
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $AllExamTypes; 
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$AllExamTypes[$SearchRow->examTypeID]['ExamType'] = $SearchRow->examType;
                
                $AllExamTypes[$SearchRow->examTypeID]['ExamStartDate'] = $SearchRow->examStartDate;
				$AllExamTypes[$SearchRow->examTypeID]['ExamEndDate'] = $SearchRow->examEndDate;
				
				$AllExamTypes[$SearchRow->examTypeID]['IsActive'] = $SearchRow->isActive;
				$AllExamTypes[$SearchRow->examTypeID]['IsVisibleForParent'] = $SearchRow->isVisibleForParent;

				$AllExamTypes[$SearchRow->examTypeID]['CreateUserID'] = $SearchRow->createUserID;
				$AllExamTypes[$SearchRow->examTypeID]['CreateUserName'] = $SearchRow->createUserName;
				$AllExamTypes[$SearchRow->examTypeID]['CreateDate'] = $SearchRow->createDate;
			}
			
			return $AllExamTypes;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ExamType::GetAllExamTypes(). Stack Trace: ' . $e->getTraceAsString());
			return $AllExamTypes;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ExamType::GetAllExamTypes(). Stack Trace: ' . $e->getTraceAsString());
			return $AllExamTypes;
		}
	}

	static function GetActiveExamTypes()
	{
		$ActiveExamTypes = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT * FROM aem_exam_types WHERE isActive = 1;');
			$RSSearch->Execute();
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $ActiveExamTypes;
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$ActiveExamTypes[$SearchRow->examTypeID] = $SearchRow->examType;				
			}
			
			return $ActiveExamTypes;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ExamType::GetActiveExamTypes(). Stack Trace: ' . $e->getTraceAsString());
			return $ActiveExamTypes;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ExamType::GetActiveExamTypes(). Stack Trace: ' . $e->getTraceAsString());
			return $ActiveExamTypes;
		}		
	}
	
	static function GetExamTypesVisibleForParent()
	{
		$VisibleForParentExamTypes = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT * FROM aem_exam_types WHERE isVisibleForParent = 1;');
			$RSSearch->Execute();
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $VisibleForParentExamTypes;
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$VisibleForParentExamTypes[$SearchRow->examTypeID] = $SearchRow->examType;				
			}
			
			return $VisibleForParentExamTypes;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ExamType::GetExamTypesVisibleForParent(). Stack Trace: ' . $e->getTraceAsString());
			return $VisibleForParentExamTypes;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ExamType::GetExamTypesVisibleForParent(). Stack Trace: ' . $e->getTraceAsString());
			return $VisibleForParentExamTypes;
		}		
	}
	
	static function GetAllStudentPhysiqueDetails($ClassSectionID, $ExamTypeID)
	{
		$AllStudentPhysiqueDetails = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT * FROM aem_student_physique asp
												INNER JOIN asa_students ass ON ass.studentID = asp.studentID
												WHERE classSectionID = :|1 AND examTypeID = :|2;');
			$RSSearch->Execute($ClassSectionID, $ExamTypeID);
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $AllStudentPhysiqueDetails; 
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$AllStudentPhysiqueDetails[$SearchRow->studentID]['Height'] = $SearchRow->height;
				$AllStudentPhysiqueDetails[$SearchRow->studentID]['Weight'] = $SearchRow->weight;								
			}
			
			return $AllStudentPhysiqueDetails;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ExamType::GetAllPreviousYearFeeDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $AllStudentPhysiqueDetails;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ExamType::GetAllPreviousYearFeeDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $AllStudentPhysiqueDetails;
		}
	}

	static function SaveStudentPhysiqueDetails($ExamTypeID, $StudentDetails)
	{	
		try
		{
			$DBConnObject = new DBConnect();

			foreach ($StudentDetails as $StudentID => $Details) 
			{	
					$RSSearch = $DBConnObject->Prepare('SELECT studentPhysiqueID FROM aem_student_physique WHERE examTypeID = :|1 AND studentID = :|2;');

					$RSSearch->Execute($ExamTypeID, $StudentID);

				if ($RSSearch->Result->num_rows > 0) 
				{
					$RSUpdate = $DBConnObject->Prepare('UPDATE aem_student_physique
													SET	height = :|1,
														weight = :|2
													WHERE studentPhysiqueID = :|3;');

					$RSUpdate->Execute($Details['Height'], $Details['Weight'], $RSSearch->FetchRow()->studentPhysiqueID);
				}
				else
				{
					$RSSave = $DBConnObject->Prepare('INSERT INTO aem_student_physique (examTypeID, studentID, height, weight)
													VALUES (:|1, :|2, :|3, :|4);');
			
					$RSSave->Execute($ExamTypeID, $StudentID, $Details['Height'], $Details['Weight']);
				}

			}
			return true;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ExamType::SaveStudentPhysiqueDetails(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ExamType::SaveStudentPhysiqueDetails(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}
	}
	
	static function GetStudentExamRemarks($ExamTypeID, $ClassSectionID)
	{
		$StudentRemarkList = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT * FROM aem_student_exam_remark WHERE examTypeID = :|1 AND classSectionID = :|2;');
			$RSSearch->Execute($ExamTypeID, $ClassSectionID);
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $StudentRemarkList;
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$StudentRemarkList[$SearchRow->studentID] = $SearchRow->remark;				
			}
			
			return $StudentRemarkList;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ExamType::GetStudentExamRemarks(). Stack Trace: ' . $e->getTraceAsString());
			return $StudentRemarkList;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ExamType::GetStudentExamRemarks(). Stack Trace: ' . $e->getTraceAsString());
			return $StudentRemarkList;
		}		
	}
	
	// END OF STATIC METHODS	//
	
	// START OF PRIVATE METHODS	//
    private function SaveDetails()
	{
		if ($this->ExamTypeID == 0)
		{
			$RSSave = $this->DBObject->Prepare('INSERT INTO aem_exam_types (examType, examStartDate, examEndDate, isActive, isVisibleForParent, createUserID, createDate)
														VALUES (:|1, :|2, :|3, :|4, :|5, :|6, NOW());');
		
			$RSSave->Execute($this->ExamType, $this->ExamStartDate, $this->ExamEndDate, $this->IsActive, $this->IsVisibleForParent, $this->CreateUserID);
			
			$this->ExamTypeID = $RSSave->LastID;
		}
		else
		{
			$RSUpdate = $this->DBObject->Prepare('UPDATE aem_exam_types
													SET	examType = :|1,
														examStartDate = :|2,
														examEndDate = :|3,
														isActive = :|4,
														isVisibleForParent = :|5
													WHERE examTypeID = :|6;');
													
			$RSUpdate->Execute($this->ExamType, $this->ExamStartDate, $this->ExamEndDate, $this->IsActive, $this->IsVisibleForParent, $this->ExamTypeID);
		}
		
		return true;
	}
	
	private function RemoveExamType()
    {
        if(!isset($this->ExamTypeID)) 
        {
            throw new ApplicationARException('', APP_AR_ERROR_DELETE_WITHOUT_ID);
        }
        
        $RSDeleteExamType = $this->DBObject->Prepare('DELETE FROM aem_exam_types WHERE examTypeID = :|1 LIMIT 1;');
        $RSDeleteExamType->Execute($this->ExamTypeID);  

        return true;              
    }
	
	private function GetExamTypeByID()
	{
		$RSExamType = $this->DBObject->Prepare('SELECT * FROM aem_exam_types WHERE examTypeID = :|1 LIMIT 1;');
		$RSExamType->Execute($this->ExamTypeID);
		
		$ExamTypeRow = $RSExamType->FetchRow();
		
		$this->SetAttributesFromDB($ExamTypeRow);				
	}
	
	private function SetAttributesFromDB($ExamTypeRow)
	{
		$this->ExamTypeID = $ExamTypeRow->examTypeID;
		$this->ExamType = $ExamTypeRow->examType;
		$this->ExamStartDate = $ExamTypeRow->examStartDate;
		$this->ExamEndDate = $ExamTypeRow->examEndDate;

		$this->IsActive = $ExamTypeRow->isActive;
		$this->IsVisibleForParent = $ExamTypeRow->isVisibleForParent;

		$this->CreateUserID = $ExamTypeRow->createUserID;
		$this->CreateDate = $ExamTypeRow->createDate;
	}	
}
?>