<?php
require_once($_SERVER['DOCUMENT_ROOT'] . '/classes/class.db_connect.php');
error_reporting(E_ALL);

class StockIssue
{
	// CLASS MEMBERS ARE DEFINED HERE	//
	private $LastErrorCode;
	private $DBObject; // VARIABLE TO HOLD THE DB CONNECTION //
	
	private $StockIssueID;
	private $ProductID;

	private $IssueType;
	private $DepartmentID;
	private $BranchStaffID;

	private $IssuedQuantity;
	private $IssueDate;
	private $ReturnDate;

	private $CreateUserID;
	private $CreateDate;
	
	// PUBLIC METHODS START HERE	//
	public function __construct($StockIssueID = 0)
	{
		$this->DBObject = new DBConnect;
		$this->LastErrorCode = 0;
		
		if($StockIssueID != 0)
		{
			$this->StockIssueID = $StockIssueID;
			// SET THE VALUES FROM THE DATABASE.
			$this->GetStockIssueByID();
		}
		else
		{
			//SET THE DEFAULT VALUES TO LOOK ATTRIBUTES
			$this->StockIssueID = 0;
			$this->ProductID = '';

			$this->IssueType = 'Staff';
			$this->DepartmentID = 0;
			$this->BranchStaffID = 0;

			$this->IssuedQuantity = 0;
			$this->IssueDate = '0000-00-00';
			$this->ReturnDate = '0000-00-00';

			$this->CreateUserID = 0;
			$this->CreateDate = '0000-00-00 00:00:00';
		}
	}
	
	// GETTER AND SETTER FUNCTIONS START HERE	//
	public function GetStockIssueID()
	{
		return $this->StockIssueID;
	}
	
	public function GetProductID()
	{
		return $this->ProductID;
	}
	public function SetProductID($ProductID)
	{
		$this->ProductID = $ProductID;
	}

	public function GetIssueType()
	{
		return $this->IssueType;
	}
	public function SetIssueType($IssueType)
	{
		$this->IssueType = $IssueType;
	}
	
	public function GetDepartmentID()
	{
		return $this->DepartmentID;
	}
	public function SetDepartmentID($DepartmentID)
	{
		$this->DepartmentID = $DepartmentID;
	}
	
	public function GetBranchStaffID()
	{
		return $this->BranchStaffID;
	}
	public function SetBranchStaffID($BranchStaffID)
	{
		$this->BranchStaffID = $BranchStaffID;
	}

	public function GetIssuedQuantity()
	{
		return $this->IssuedQuantity;
	}
	public function SetIssuedQuantity($IssuedQuantity)
	{
		$this->IssuedQuantity = $IssuedQuantity;
	}

	public function GetIssueDate()
	{
		return $this->IssueDate;
	}
	public function SetIssueDate($IssueDate)
	{
		$this->IssueDate = $IssueDate;
	}	
	
	public function GetReturnDate()
	{
		return $this->ReturnDate;
	}
	public function SetReturnDate($ReturnDate)
	{
		$this->ReturnDate = $ReturnDate;
	}
	
	public function GetCreateUserID()
	{
		return $this->CreateUserID;
	}
	public function SetCreateUserID($CreateUserID)
	{
		$this->CreateUserID = $CreateUserID;
	}
	
	public function GetCreateDate()
	{
		return $this->CreateDate;
	}
	
	public function GetLastErrorCode()
	{
		return $this->LastErrorCode;
	}
	
	//  END OF GETTER AND SETTER FUNCTIONS 	//
	
	public function Save()
	{
		try
		{
			return $this->SaveDetails();
		}
		catch (ApplicationDBException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (ApplicationARException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (Exception $e)
		{
			$this->LastErrorCode = APP_ERROR_UNDEFINED_ERROR;
			return false;
		}
	}

	public function Remove()
	{
		try
		{
			$this->RemoveStockIssue();
			return true;
		}
		catch (ApplicationDBException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (ApplicationARException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (Exception $e)
		{
			$this->LastErrorCode = APP_ERROR_UNDEFINED_ERROR;
			return false;
		}
	}
	
	public function CheckDependencies()
	{
		try
		{
			$RSTotal = $this->DBObject->Prepare('SELECT COUNT(*) AS totalRecords FROM role_group_roles WHERE stockIssueID = :|1;');
			$RSTotal->Execute($this->StockIssueID);
	
			if ($RSTotal->FetchRow()->totalRecords > 0) 
			{
				return true;
			}
			
			return false;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException: StockIssue::CheckDependencies(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception: StockIssue::CheckDependencies(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
	}

	public function RecordExists()
	{
		try
		{
			$QueryString = '';
			
			if ($this->StockIssueID > 0)
			{
				$QueryString = ' AND stockIssueID != ' . $this->DBObject->RealEscapeVariable($this->StockIssueID);
			}

			$RSTotal = $this->DBObject->Prepare('SELECT COUNT(*) AS totalRecords FROM aim_stock_issue WHERE productID = :|1' . $QueryString . ';');
			$RSTotal->Execute($this->ProductID);
			
			if ($RSTotal->FetchRow()->totalRecords > 0)
			{
				return true;
			}
			
			return false;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockIssue::RecordExists(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockIssue::RecordExists(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
	}

	// END OF PUBLIC METHODS	//
	
	// START OF STATIC METHODS	//
	static function GetAllStockIssues()
    { 
		$AllStockIssues = array();
		
    	try
        {	
        	$DBConnObject = new DBConnect();
        	$RSSearch = $DBConnObject->Prepare('SELECT asi.*, ap.productName, apc.productCategoryName, ad.departmentName, CONCAT(abs.firstName, " ", abs.lastName) AS branchStaffName, 
        											u.userName AS createUserName FROM aim_stock_issue asi 
        											INNER JOIN aim_products ap ON asi.productID = ap.productID
        											INNER JOIN aim_product_categories apc ON ap.productCategoryID = apc.productCategoryID
        											LEFT JOIN aim_departments ad ON asi.departmentID = ad.departmentID
        											INNER JOIN asa_branch_staff abs ON asi.branchStaffID = abs.branchStaffID
													INNER JOIN users u ON asi.createUserID = u.userID 
        											ORDER BY asi.stockIssueID;');
            $RSSearch->Execute();

            if ($RSSearch->Result->num_rows <= 0)
            {
                return $AllStockIssues;
            }

            while($SearchRow = $RSSearch->FetchRow())
            {
                $AllStockIssues[$SearchRow->stockIssueID]['ProductID'] = $SearchRow->productID;
                $AllStockIssues[$SearchRow->stockIssueID]['ProductCategoryName'] = $SearchRow->productCategoryName;
                $AllStockIssues[$SearchRow->stockIssueID]['ProductName'] = $SearchRow->productName;

				$AllStockIssues[$SearchRow->stockIssueID]['IssueType'] = $SearchRow->issueType;
				$AllStockIssues[$SearchRow->stockIssueID]['DepartmentName'] = $SearchRow->departmentName;
				$AllStockIssues[$SearchRow->stockIssueID]['BranchStaffName'] = $SearchRow->branchStaffName;
				
				$AllStockIssues[$SearchRow->stockIssueID]['IssuedQuantity'] = $SearchRow->issuedQuantity;
				$AllStockIssues[$SearchRow->stockIssueID]['IssueDate'] = $SearchRow->issueDate;
				$AllStockIssues[$SearchRow->stockIssueID]['ReturnDate'] = $SearchRow->returnDate;

                $AllStockIssues[$SearchRow->stockIssueID]['CreateUserID'] = $SearchRow->createUserID;
                $AllStockIssues[$SearchRow->stockIssueID]['CreateUserName'] = $SearchRow->createUserName;

                $AllStockIssues[$SearchRow->stockIssueID]['CreateDate'] = $SearchRow->createDate;
           }
            
            return $AllStockIssues;
        }
        catch (ApplicationDBException $e)
        {
            error_log('DEBUG: ApplicationDBException::StockIssue::GetAllStockIssues(). Stack Trace: '. $e->getTraceAsString());
            return $AllStockIssues;
        }
        catch (Exception $e)
        {
            error_log('DEBUG: Exception: StockIssue::GetAllStockIssues() . Stack Trace: '. $e->getTraceAsString());
            return $AllStockIssues;
        }
    }

    static function GetActiveStockIssues()
	{
		$AllStockIssues = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT * FROM aim_stock_issue WHERE issueType = 1;');
			$RSSearch->Execute();
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $AllStockIssues;
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$AllStockIssues[$SearchRow->stockIssueID] = $SearchRow->productID;
			}
			
			return $AllStockIssues;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockIssue::GetActiveStockIssues(). Stack Trace: ' . $e->getTraceAsString());
			return $AllStockIssues;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockIssue::GetActiveStockIssues(). Stack Trace: ' . $e->getTraceAsString());
			return $AllStockIssues;
		}		
	}

	static function GetStockQunatity($ProductID)
	{	
		$StockQuantity = 0;
		$TotalIssuedQunatityToDepartment = 0;
		$TotalQuantityIssuedByDepartment = 0;

		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearchIssuedQunatityToDepartment = $DBConnObject->Prepare('SELECT sum(issuedQuantity) as totalIssuedQunatityToDepartment FROM aim_stock_issue
														  					WHERE productID = :|1 AND issueType = "Department" LIMIT 1;');
			$RSSearchIssuedQunatityToDepartment->Execute($ProductID);

			$RSSearchRowIssuedQunatityToDepartment = $RSSearchIssuedQunatityToDepartment->FetchRow();

			$RSSearchQuantityIssuedByDepartment = $DBConnObject->Prepare('SELECT sum(issuedQuantity) AS totalQuantityIssuedByDepartment 
																			FROM aim_department_stock_issue WHERE productID = :|1 LIMIT 1;');
			$RSSearchQuantityIssuedByDepartment->Execute($ProductID);

			$RSSearchRowQuantityIssuedByDepartment = $RSSearchQuantityIssuedByDepartment->FetchRow();

			if (count($RSSearchRowIssuedQunatityToDepartment) > 0) 
			{
				$TotalIssuedQunatityToDepartment = $RSSearchRowIssuedQunatityToDepartment->totalIssuedQunatityToDepartment;			
			}

			if (count($RSSearchRowQuantityIssuedByDepartment) > 0) 
			{
				$TotalQuantityIssuedByDepartment = $RSSearchRowQuantityIssuedByDepartment->totalQuantityIssuedByDepartment;			
			}

			$StockQuantity = $TotalIssuedQunatityToDepartment - $TotalQuantityIssuedByDepartment;
			
			return $StockQuantity;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockIssue::GetStockQunatity(). Stack Trace: ' . $e->getTraceAsString());
			return $StockQuantity;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockIssue::GetStockQunatity(). Stack Trace: ' . $e->getTraceAsString());
			return $StockQuantity;
		}		
	}

	static function GetProductsByDepartmentID($DepartmentID)
	{
		$AllProducts = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT asi.productID, ap.productName FROM aim_stock_issue asi 
												INNER JOIN aim_products ap ON asi.productID = ap.productID
												WHERE asi.departmentID = :|1 AND asi.issueType = "Department";');
			$RSSearch->Execute($DepartmentID);
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $AllProducts;
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$AllProducts[$SearchRow->productID] = $SearchRow->productName;
			}
			
			return $AllProducts;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockIssue::GetProductsByDepartmentID(). Stack Trace: ' . $e->getTraceAsString());
			return $AllProducts;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockIssue::GetProductsByDepartmentID(). Stack Trace: ' . $e->getTraceAsString());
			return $AllProducts;
		}		
	}
    
	// END OF STATIC METHODS	//
	
	// START OF PRIVATE METHODS	//
	private function SaveDetails()
	{	
		$StockQuantity = 0;

		if ($this->StockIssueID == 0)
		{
			$RSSave = $this->DBObject->Prepare('INSERT INTO aim_stock_issue (productID, issueType, departmentID, branchStaffID, issuedQuantity, issueDate, 
																				returnDate, createUserID, createDate)
														VALUES (:|1, :|2, :|3, :|4, :|5, :|6, :|7, :|8, NOW());');
			$RSSave->Execute($this->ProductID, $this->IssueType, $this->DepartmentID, $this->BranchStaffID, $this->IssuedQuantity, $this->IssueDate, 
									$this->ReturnDate, $this->CreateUserID);

			$this->StockIssueID = $RSSave->LastID;

			$RSSearchProducts = $this->DBObject->Prepare('SELECT stockQuantity FROM aim_products WHERE productID = :|1 LIMIT 1;');
			$RSSearchProducts->Execute($this->ProductID);

			$StockQuantity = $RSSearchProducts->FetchRow()->stockQuantity - $this->IssuedQuantity;

			$RSUpdateProductStock = $this->DBObject->Prepare('UPDATE aim_products
																SET	stockQuantity = :|1
																WHERE productID = :|2 LIMIT 1;');
			$RSUpdateProductStock->Execute($StockQuantity, $this->ProductID);
		}
		else
		{	
			$RSSearchStockIssue = $this->DBObject->Prepare('SELECT issuedQuantity, productID FROM aim_stock_issue WHERE stockIssueID = :|1 LIMIT 1;');
			$RSSearchStockIssue->Execute($this->StockIssueID);

			$SearchRowStockIssue = $RSSearchStockIssue->FetchRow();

			$RSSearchProducts = $this->DBObject->Prepare('SELECT stockQuantity FROM aim_products WHERE productID = :|1 LIMIT 1;');
			$RSSearchProducts->Execute($SearchRowStockIssue->productID);

			$StockQuantity = 0; 

			$StockQuantity = $RSSearchProducts->FetchRow()->stockQuantity - $SearchRowStockIssue->issuedQuantity;

			$RSUpdateProductStock = $this->DBObject->Prepare('UPDATE aim_products
																SET	stockQuantity = :|1
																WHERE productID = :|2 LIMIT 1;');
			$RSUpdateProductStock->Execute($StockQuantity, $SearchRowStockIssue->productID);


			$RSSearchProducts = $this->DBObject->Prepare('SELECT stockQuantity FROM aim_products WHERE productID = :|1 LIMIT 1;');
			$RSSearchProducts->Execute($this->ProductID);

			$StockQuantity = 0;
			$StockQuantity = $RSSearchProducts->FetchRow()->stockQuantity  + $this->IssuedQuantity;

			$RSUpdate = $this->DBObject->Prepare('UPDATE aim_stock_issue
													SET	productID = :|1,
														issueType = :|2,
														departmentID = :|3,
														branchStaffID = :|4,
														issuedQuantity = :|5,
														issueDate = :|6,
														returnDate = :|7
													WHERE stockIssueID = :|8 LIMIT 1;');
			$RSUpdate->Execute($this->ProductID, $this->IssueType, $this->DepartmentID, $this->BranchStaffID, $this->IssuedQuantity, $this->IssueDate, 
									$this->ReturnDate, $this->StockIssueID);

			$RSUpdateProductStock = $this->DBObject->Prepare('UPDATE aim_products
																SET	stockQuantity = :|1
																WHERE productID = :|2 LIMIT 1;');
			$RSUpdateProductStock->Execute($StockQuantity, $this->ProductID);

		}
		
		return true;
	}

	private function RemoveStockIssue()
	{
		if(!isset($this->StockIssueID)) 
		{
    		throw new ApplicationARException('', APP_AR_ERROR_DELETE_WITHOUT_ID);
		}
		
		$RSDeleteStockIssue = $this->DBObject->Prepare('DELETE FROM aim_stock_issue WHERE stockIssueID = :|1 LIMIT 1;');
		$RSDeleteStockIssue->Execute($this->StockIssueID);				
	}
	
	private function GetStockIssueByID()
	{
		$RSStockIssue = $this->DBObject->Prepare('SELECT * FROM aim_stock_issue WHERE stockIssueID = :|1 LIMIT 1;');
		$RSStockIssue->Execute($this->StockIssueID);
		
		$StockIssueRow = $RSStockIssue->FetchRow();
		
		$this->SetAttributesFromDB($StockIssueRow);				
	}
	
	private function SetAttributesFromDB($StockIssueRow)
	{
		$this->StockIssueID = $StockIssueRow->stockIssueID;
		$this->ProductID = $StockIssueRow->productID;

		$this->IssueType = $StockIssueRow->issueType;
		$this->DepartmentID = $StockIssueRow->departmentID;
		$this->BranchStaffID = $StockIssueRow->branchStaffID;

		$this->IssuedQuantity = $StockIssueRow->issuedQuantity;
		$this->IssueDate = $StockIssueRow->issueDate;
		$this->ReturnDate = $StockIssueRow->issueDate;

		$this->CreateUserID = $StockIssueRow->createUserID;
		$this->CreateDate = $StockIssueRow->createDate;
	}	
}
?>