<?php
require_once($_SERVER['DOCUMENT_ROOT'] . '/classes/class.db_connect.php');
error_reporting(E_ALL);

class ClassHelpers
{
	static function SaveClassSectionTimeTable($ClassSectionID, $LoggedUserID, $TimeTableDetails)
	{
		try
		{
			$DBConnObject = new DBConnect();

			$DBConnObject->BeginTransaction();

			$RSDeleteTimeTableDetails = $DBConnObject->Prepare('DELETE FROM asa_class_time_table_details WHERE classTimeTableID IN (SELECT classTimeTableID FROM asa_class_time_table WHERE classSectionID = :|1);');
			$RSDeleteTimeTableDetails->Execute($ClassSectionID);
			
			$RSDeleteTimeTable = $DBConnObject->Prepare('DELETE FROM asa_class_time_table WHERE classSectionID = :|1;');
			$RSDeleteTimeTable->Execute($ClassSectionID);
			
			foreach ($TimeTableDetails as $DaywiseTimingsID => $DaywiseTimingDetails)
			{
				$RSSaveTimeTable = $DBConnObject->Prepare('INSERT INTO asa_class_time_table (classSectionID, daywiseTimingsID, isActive, createUserID, createDate) 
																VALUES (:|1, :|2, :|3, :|4, NOW());');

				$RSSaveTimeTable->Execute($ClassSectionID, $DaywiseTimingsID, 1, $LoggedUserID);

				$ClassTimeTableID = $RSSaveTimeTable->LastID;

				foreach ($DaywiseTimingDetails as $PeriodTimingID => $PeriodTimingDetails)
				{
					$RSSaveTimeTableDetails = $DBConnObject->Prepare('INSERT INTO asa_class_time_table_details (classTimeTableID, periodTimingID, classSubjectID, teacherClassID) 
																			VALUES (:|1, :|2, :|3, :|4);');

					$RSSaveTimeTableDetails->Execute($ClassTimeTableID, $PeriodTimingID, $PeriodTimingDetails['ClassSubjectID'], $PeriodTimingDetails['TeacherClassID']);
				}
			}

			$DBConnObject->CommitTransaction();

            return true;
		}
		catch (ApplicationDBException $e)
        {
			error_log('DEBUG: ApplicationDBException at ClassHelpers::SaveClassSectionTimeTable(). Stack Trace: '.$e->getTraceAsString());
			$DBConnObject->RollBackTransaction();
            return false;
        }
        catch (Exception $e)
        {
			error_log('DEBUG: Exception at ClassHelpers::SaveClassSectionTimeTable(). Stack Trace: '.$e->getTraceAsString());
			$DBConnObject->RollBackTransaction();
            return false;
        }
	}

	static function GetClassSectionTimeTable($ClassSectionID, $GetOnlyActiveRecords = true)
	{
		$ClassTimeTable = array();
		
		try
		{
			$DBConnObject = new DBConnect();

			$QueryString = '';
			
			if ($GetOnlyActiveRecords)
			{
				$QueryString = ' AND actt.isActive = 1';
			}

			$RSGetClassSectionTimeTable = $DBConnObject->Prepare('SELECT actt.daywiseTimingsID, acttd.periodTimingID, acttd.classSubjectID, acttd.teacherClassID, asm.subject, abs.firstName, abs.lastName 
																  FROM asa_class_time_table actt 
																  INNER JOIN asa_class_time_table_details acttd ON acttd.classTimeTableID = actt.classTimeTableID 
																  INNER JOIN asa_class_subjects acs ON acs.classSubjectID = acttd.classSubjectID 
																  INNER JOIN asa_subject_master asm ON asm.subjectID = acs.subjectID 
																  INNER JOIN asa_teacher_classes atc ON atc.teacherClassID = acttd.teacherClassID 
																  INNER JOIN asa_branch_staff abs ON abs.branchStaffID = atc.branchStaffID 
																  WHERE actt.classSectionID = :|1'.$QueryString.';');

			$RSGetClassSectionTimeTable->Execute($ClassSectionID);

			if ($RSGetClassSectionTimeTable->Result->num_rows <= 0)
			{
				return $ClassTimeTable;
			}

			while ($SearchClassSectionTimeTableRow = $RSGetClassSectionTimeTable->FetchRow())
			{
				$ClassTimeTable[$SearchClassSectionTimeTableRow->daywiseTimingsID][$SearchClassSectionTimeTableRow->periodTimingID]['ClassSubjectID'] = $SearchClassSectionTimeTableRow->classSubjectID;
				$ClassTimeTable[$SearchClassSectionTimeTableRow->daywiseTimingsID][$SearchClassSectionTimeTableRow->periodTimingID]['TeacherClassID'] = $SearchClassSectionTimeTableRow->teacherClassID;

				$ClassTimeTable[$SearchClassSectionTimeTableRow->daywiseTimingsID][$SearchClassSectionTimeTableRow->periodTimingID]['ClassSubjectName'] = $SearchClassSectionTimeTableRow->subject;
				$ClassTimeTable[$SearchClassSectionTimeTableRow->daywiseTimingsID][$SearchClassSectionTimeTableRow->periodTimingID]['TeacherClassName'] = $SearchClassSectionTimeTableRow->firstName.' '.$SearchClassSectionTimeTableRow->lastName;
			}

            return $ClassTimeTable;
		}
		catch (ApplicationDBException $e)
        {
			error_log('DEBUG: ApplicationDBException at ClassHelpers::GetClassSectionTimeTable(). Stack Trace: '.$e->getTraceAsString());
            return $ClassTimeTable;
        }
        catch (Exception $e)
        {
			error_log('DEBUG: Exception at ClassHelpers::GetClassSectionTimeTable(). Stack Trace: '.$e->getTraceAsString());
            return $ClassTimeTable;
        }
	}
	
	static function SaveStudentTCDetails($StudentIDList, $LastDateOfSession, $TcIssueDate, $SchoolLeavingDate, $ReasonOfLeaving, $CreateUserID)
	{		
		try
		{
			$DBConnObject = new DBConnect();
			
			if (count($StudentIDList) > 0) 
			{
			    $TcNumber = 0;
			    
			    $RSSearchLastTcNumber = $DBConnObject->Prepare('SELECT MAX(tcNumber) AS tcNumber FROM asa_student_tc_details LIMIT 1;');
		        $RSSearchLastTcNumber->Execute();
		        
		        if ($RSSearchLastTcNumber->Result->num_rows > 0)
		        {
		            $TcNumber = $RSSearchLastTcNumber->FetchRow()->tcNumber;
		        }
		        
				foreach ($StudentIDList as $Key => $StudentID) 
				{
				    $RSSearch = $DBConnObject->Prepare('SELECT count(*) AS totalRecords FROM asa_student_tc_details WHERE studentID = :|1;');
    		        $RSSearch->Execute($StudentID);
    		        
    		        if ($RSSearch->FetchRow()->totalRecords > 0)
    		        {
    		            continue;
    		        }
    		        
					$RSSave = $DBConnObject->Prepare('INSERT INTO asa_student_tc_details (studentID, tcNumber, resultStatus, nccCadet, generalConduct, lastDateOfSession, tcIssueDate, schoolLeavingDate, reasonOfLeaving, otherRemark, createUserID, createDate)
														VALUES (:|1, :|2, :|3, :|4, :|5, :|6, :|7, :|8, :|9, :|10, :|11, NOW());');
					$RSSave->Execute($StudentID, ++$TcNumber, 'Yes', '', 'Satisfactory', $LastDateOfSession, $TcIssueDate, $SchoolLeavingDate, $ReasonOfLeaving, '', $CreateUserID);
					
					$RSUpdateStudent = $DBConnObject->Prepare('UPDATE asa_students
    															SET	status = :|1
    															WHERE studentID = :|2 LIMIT 1;');
    													
    				$RSUpdateStudent->Execute('TC', $StudentID);
				}
			}
			
			return true;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ClassHelpers::SaveStudentTCDetails(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ClassHelpers::SaveStudentTCDetails(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}		
	}
	
	static function GetStudentClubActivities($StudentID)
	{		
	    $ClubActivities = '';
	    
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT clubActivities FROM aem_student_exam_remark WHERE studentID = :|1 AND examTypeID = 4;');
	        $RSSearch->Execute($StudentID);
	        
	        if ($RSSearch->Result->num_rows <= 0)
	        {
	            return $ClubActivities;
	        }
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$ClubActivities = $SearchRow->clubActivities;
			}
			
			return $ClubActivities;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ClassHelpers::GetStudentClubActivities(). Stack Trace: ' . $e->getTraceAsString());
			return $ClubActivities;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ClassHelpers::GetStudentClubActivities(). Stack Trace: ' . $e->getTraceAsString());
			return $ClubActivities;
		}		
	}
	
	static function UpdateStudentClubActivities($StudentID, $ClubActivities)
	{		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSUpdate = $DBConnObject->Prepare('UPDATE aem_student_exam_remark
													SET	remark = :|1
													WHERE studentID = :|2 AND examTypeID = :|3 LIMIT 1;');
			$RSUpdate->Execute($ClubActivities, $StudentID, 4);
			
			return true;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ClassHelpers::UpdateStudentClubActivities(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ClassHelpers::UpdateStudentClubActivities(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}		
	}
	
	static function GetStudentTCDetails($StudentID)
	{		
	    $StudentTCDetails = array();
	    
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT * FROM asa_student_tc_details WHERE studentID = :|1;');
	        $RSSearch->Execute($StudentID);
	        
	        if ($RSSearch->Result->num_rows <= 0)
	        {
	            return $StudentTCDetails;
	        }
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$StudentTCDetails[$SearchRow->studentID]['TCNumber'] = $SearchRow->tcNumber;
				$StudentTCDetails[$SearchRow->studentID]['ResultStatus'] = $SearchRow->resultStatus;
				$StudentTCDetails[$SearchRow->studentID]['NccCadet'] = $SearchRow->nccCadet;
				$StudentTCDetails[$SearchRow->studentID]['GeneralConduct'] = $SearchRow->generalConduct;
				$StudentTCDetails[$SearchRow->studentID]['LastDateOfSession'] = $SearchRow->lastDateOfSession;
				$StudentTCDetails[$SearchRow->studentID]['TcIssueDate'] = $SearchRow->tcIssueDate;
				$StudentTCDetails[$SearchRow->studentID]['LeavingDate'] = $SearchRow->schoolLeavingDate;
				$StudentTCDetails[$SearchRow->studentID]['ReasonOfLeaving'] = $SearchRow->reasonOfLeaving;
				$StudentTCDetails[$SearchRow->studentID]['OtherRemark'] = $SearchRow->otherRemark;
			}
			
			return $StudentTCDetails;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ClassHelpers::GetStudentTCDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $StudentTCDetails;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ClassHelpers::GetStudentTCDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $StudentTCDetails;
		}		
	}
	
	static function UpdateStudentTcDetails($TcDetailsToBeUpdate)
	{		
		$UpdatedTcDetails = array();
		try
		{
			$DBConnObject = new DBConnect();
			
			if (count($TcDetailsToBeUpdate) > 0) 
			{
				foreach ($TcDetailsToBeUpdate as $StudentID => $Details) 
				{
					$RSUpdate = $DBConnObject->Prepare('UPDATE asa_student_tc_details
															SET	resultStatus = :|1,
																nccCadet = :|2,
																generalConduct = :|3,
																lastDateOfSession = :|4,
																tcIssueDate = :|5,
																schoolLeavingDate = :|6,
																reasonOfLeaving = :|7,
																otherRemark = :|8,
																createUserID = :|9,
																createDate = NOW()
															WHERE studentID = :|10 AND tcNumber = :|11 LIMIT 1;');
					$RSUpdate->Execute($Details['ResultStatus'], $Details['NccCadet'], $Details['GeneralConduct'], $Details['LastDateOfSession'], $Details['TcIssueDate'], $Details['LeavingDate'], $Details['ReasonOfLeaving'], $Details['OtherRemark'], $Details['CreateUserID'], $StudentID, $Details['TCNumber']);
				}
			}
			
			return $UpdatedTcDetails = $TcDetailsToBeUpdate;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ClassHelpers::UpdateStudentTcDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $UpdatedTcDetails;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ClassHelpers::UpdateStudentTcDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $UpdatedTcDetails;
		}		
	}
	
	static function SearchStudentTCDetails(&$TotalRecords = 0, $GetTotalsOnly = false, $Filters = array(), $Start = 0, $Limit = 100)
	{
		$TCStudentsList = array();
		
		try
		{
			$DBConnObject = new DBConnect();

			$Conditions = array();
			
			if (count($Filters) > 0)
			{
			    if (!empty($Filters['ClassID']))
				{
					$Conditions[] = 'ac.classID = '. $DBConnObject->RealEscapeVariable($Filters['ClassID']);
				}

				if (!empty($Filters['ClassSectionID']))
				{
					$Conditions[] = 'acs.classSectionID = '. $DBConnObject->RealEscapeVariable($Filters['ClassSectionID']);
				}
				
				if (!empty($Filters['StudentID']))
				{
					$Conditions[] = 'std.studentID = '. $DBConnObject->RealEscapeVariable($Filters['StudentID']);
				}
				
				if (!empty($Filters['SessionLastDate']))
				{
					$Conditions[] = 'std.lastDateOfSession = '. $DBConnObject->RealEscapeVariable($Filters['SessionLastDate']);
				}
				
				if (!empty($Filters['TCIssueDate']))
				{
					$Conditions[] = 'std.tcIssueDate = '. $DBConnObject->RealEscapeVariable($Filters['TCIssueDate']);
				}
				
				if (!empty($Filters['SchoolLeavingDate']))
				{
					$Conditions[] = 'std.schoolLeavingDate = '. $DBConnObject->RealEscapeVariable($Filters['SchoolLeavingDate']);
				}
				
				if (!empty($Filters['ReasonForLeaving']))
				{
					$Conditions[] = 'std.reasonOfLeaving = '. $DBConnObject->RealEscapeVariable($Filters['ReasonForLeaving']);
				}
				
				if (!empty($Filters['StudentName']))
				{
					$Conditions[] = 'CONCAT(asd.firstName, " ", asd.lastName) LIKE ' . $DBConnObject->RealEscapeVariable('%' . $Filters['StudentName'] . '%');
				}
			}
			
			$QueryString = '';

			if (count($Conditions) > 0)
			{
				$QueryString = implode(') AND (', $Conditions);
				
				$QueryString = ' WHERE (' . $QueryString . ')';
			}

			if ($GetTotalsOnly)
			{
				$RSTotal = $DBConnObject->Prepare('SELECT COUNT(Distinct std.studentTcDetailID) AS totalRecords 
													FROM asa_student_tc_details std
													
                                                    INNER JOIN asa_student_details asd ON asd.studentID = std.studentID 
                                                    INNER JOIN asa_students ass ON ass.studentID = asd.studentID 
                                                    INNER JOIN asa_class_sections acs ON acs.classSectionID = ass.classSectionID 
                                                    INNER JOIN asa_classes ac ON ac.classID = acs.classID 
                                                    INNER JOIN asa_section_master asm ON asm.sectionMasterID = acs.sectionMasterID 
                                                    INNER JOIN users u ON std.createUserID = u.userID
													'. $QueryString .';');
				$RSTotal->Execute();
				
				$TotalRecords = $RSTotal->FetchRow()->totalRecords;
				return;
			}
			
			$RSSearch = $DBConnObject->Prepare('SELECT std.*, ass.rollNumber, asd.firstName, asd.lastName, ac.className, asm.sectionName, u.userName AS createUserName
												FROM asa_student_tc_details std
												
                                                INNER JOIN asa_student_details asd ON asd.studentID = std.studentID 
                                                INNER JOIN asa_students ass ON ass.studentID = asd.studentID 
                                                INNER JOIN asa_class_sections acs ON acs.classSectionID = ass.classSectionID 
                                                INNER JOIN asa_classes ac ON ac.classID = acs.classID 
                                                INNER JOIN asa_section_master asm ON asm.sectionMasterID = acs.sectionMasterID 
                                                INNER JOIN users u ON std.createUserID = u.userID
												'. $QueryString .'
												ORDER BY asd.firstName, asd.lastName LIMIT ' . (int) $Start . ', ' . (int) $Limit . ';');
			$RSSearch->Execute();
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $TCStudentsList; 
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
			    $TCStudentsList[$SearchRow->studentTcDetailID]['StudentID'] = $SearchRow->studentID;
				$TCStudentsList[$SearchRow->studentTcDetailID]['StudentName'] = $SearchRow->firstName .' '. $SearchRow->lastName;
				$TCStudentsList[$SearchRow->studentTcDetailID]['RollNumber'] = $SearchRow->rollNumber;

				$TCStudentsList[$SearchRow->studentTcDetailID]['ClassName'] = $SearchRow->className;
				$TCStudentsList[$SearchRow->studentTcDetailID]['SectionName'] = $SearchRow->sectionName;
				
				$TCStudentsList[$SearchRow->studentTcDetailID]['TcNumber'] = $SearchRow->tcNumber;
				$TCStudentsList[$SearchRow->studentTcDetailID]['ResultStatus'] = $SearchRow->resultStatus;
				$TCStudentsList[$SearchRow->studentTcDetailID]['NccCadet'] = $SearchRow->nccCadet;
				$TCStudentsList[$SearchRow->studentTcDetailID]['GeneralConduct'] = $SearchRow->generalConduct;
				$TCStudentsList[$SearchRow->studentTcDetailID]['LastDateOfSession'] = $SearchRow->lastDateOfSession;
				$TCStudentsList[$SearchRow->studentTcDetailID]['TcIssueDate'] = $SearchRow->tcIssueDate;
				$TCStudentsList[$SearchRow->studentTcDetailID]['SchoolLeavingDate'] = $SearchRow->schoolLeavingDate;
				$TCStudentsList[$SearchRow->studentTcDetailID]['ReasonOfLeaving'] = $SearchRow->reasonOfLeaving;
				$TCStudentsList[$SearchRow->studentTcDetailID]['OtherRemark'] = $SearchRow->otherRemark;
				 			
				$TCStudentsList[$SearchRow->studentTcDetailID]['CreateUserName'] = $SearchRow->createUserName;
				$TCStudentsList[$SearchRow->studentTcDetailID]['CreateDate'] = $SearchRow->createDate;
			}
			
			return $TCStudentsList;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ClassHelpers::SearchStudentTCDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $TCStudentsList;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ClassHelpers::SearchStudentTCDetails(). Stack Trace: ' . $e->getTraceAsString());
			return $TCStudentsList;
		}
	}
	
	static function DeleteStudentTC($StudentID)
	{		
		try
		{
			$DBConnObject = new DBConnect();
			
		    $RSDeleteTC = $DBConnObject->Prepare('DELETE FROM asa_student_tc_details WHERE studentID = :|1;');
	        $RSDeleteTC->Execute($StudentID);
	        
	        $RSUpdateStudent = $DBConnObject->Prepare('UPDATE asa_students
														SET	status = :|1
														WHERE studentID = :|2 LIMIT 1;');
												
			$RSUpdateStudent->Execute('Active', $StudentID);
			
			return true;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at ClassHelpers::DeleteStudentTC(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at ClassHelpers::DeleteStudentTC(). Stack Trace: ' . $e->getTraceAsString());
			return false;
		}		
	}
}
?>